function parse(path__2) {
    const isAbsolute__2 = path__2.charCodeAt(0) === CHAR_FORWARD_SLASH;
    if (isAbsolute__2) {}
}
function isAbsolute() {}
